(FAMILY ot1-stixgeneral)
(CODINGSCHEME STIXOT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 40)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 450)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 13) (comment ff)
   (LIG C l O 17)
   (LIG C i O 16)
   (STOP)
   (LABEL O 32) (comment ae)
   (KRN C v R -28)
   (KRN C w R -29)
   (KRN C y R -30)
   (STOP)
   (LABEL O 34) (comment oslash)
   (KRN O 47 R -36) (comment quoteright)
   (KRN C y R -22)
   (KRN C x R -22)
   (KRN C w R -22)
   (KRN C v R -22)
   (KRN C t R -8)
   (KRN C T R -87)
   (STOP)
   (LABEL O 37) (comment Oslash)
   (KRN O 35 R -24) (comment AE)
   (KRN C Y R -36)
   (KRN C X R -25)
   (KRN C W R -25)
   (KRN C V R -30)
   (KRN C T R -3)
   (KRN C A R -25)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 74)
   (STOP)
   (LABEL O 42) (comment quotedblright)
   (KRN C A R -96)
   (KRN C T R 9)
   (KRN C V R 1)
   (KRN C W R 6)
   (KRN C Y R -3)
   (KRN O 35 R -99) (comment AE)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 42)
   (KRN O 34 R -56) (comment oslash)
   (KRN O 54 R -73) (comment comma)
   (KRN O 56 R -80) (comment period)
   (KRN C A R -132)
   (KRN C d R -58)
   (KRN C o R -56)
   (KRN C r R -38)
   (KRN C s R -49)
   (KRN C t R -42)
   (KRN C v R -48)
   (KRN C w R -43)
   (KRN C y R -46)
   (KRN O 35 R -135) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN O 47 R -58) (comment quoteright)
   (KRN O 42 R -34) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 173)
   (KRN C A R -30)
   (KRN C T R -79)
   (KRN C V R -78)
   (KRN C W R -45)
   (KRN C Y R -95)
   (KRN O 35 R -26) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -37) (comment quoteright)
   (KRN O 42 R -37) (comment quotedblright)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 76)
   (STOP)
   (LABEL C A)
   (KRN O 34 R -26) (comment oslash)
   (KRN O 37 R -25) (comment Oslash)
   (KRN O 54 R -2) (comment comma)
   (KRN O 55 R -16) (comment hyphen)
   (KRN O 56 R -5) (comment period)
   (KRN C C R -25)
   (KRN C G R -25)
   (KRN C O R -25)
   (KRN C Q R -25)
   (KRN C T R -54)
   (KRN C U R -35)
   (KRN C V R -83)
   (KRN C W R -83)
   (KRN C Y R -52)
   (KRN C a R -4)
   (KRN C b R -14)
   (KRN C c R -10)
   (KRN C d R -17)
   (KRN C e R -16)
   (KRN C g R -12)
   (KRN C o R -26)
   (KRN C q R -14)
   (KRN C t R -13)
   (KRN C u R -14)
   (KRN C v R -58)
   (KRN C w R -58)
   (KRN C y R -72)
   (KRN O 47 R -74) (comment quoteright)
   (KRN O 42 R -57) (comment quotedblright)
   (STOP)
   (LABEL C B)
   (KRN C A R -33)
   (KRN C O R -17)
   (KRN C V R -50)
   (KRN C W R -47)
   (KRN C Y R -60)
   (KRN O 35 R -28) (comment AE)
   (KRN O 37 R -17) (comment Oslash)
   (KRN O 36 R -17) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 37 R -8) (comment Oslash)
   (KRN C A R -16)
   (KRN C K R -9)
   (KRN C O R -8)
   (KRN O 35 R -11) (comment AE)
   (STOP)
   (LABEL C D)
   (KRN C A R -40)
   (KRN C J R -20)
   (KRN C T R -5)
   (KRN C V R -38)
   (KRN C W R -38)
   (KRN C X R -42)
   (KRN C Y R -46)
   (STOP)
   (LABEL C F)
   (KRN O 37 R -1) (comment Oslash)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R 3) (comment hyphen)
   (KRN O 56 R -47) (comment period)
   (KRN C A R -35)
   (KRN C J R -1)
   (KRN C O R -1)
   (KRN C a R -11)
   (KRN C e R -4)
   (KRN C i R -5)
   (KRN C j R -5)
   (KRN C o R -5)
   (KRN C r R -1)
   (KRN C u R -1)
   (KRN O 32 R -15) (comment ae)
   (KRN O 34 R -5) (comment oslash)
   (KRN O 33 R -5) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN C A R -15)
   (KRN C T R -13)
   (KRN C V R -15)
   (KRN C W R -15)
   (KRN C Y R -21)
   (KRN O 35 R -11) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN C A R -35)
   (KRN O 35 R -30) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 34 R -15) (comment oslash)
   (KRN O 37 R -19) (comment Oslash)
   (KRN O 55 R -50) (comment hyphen)
   (KRN C C R -19)
   (KRN C G R -19)
   (KRN C O R -19)
   (KRN C S R 1)
   (KRN C T R -1)
   (KRN C a R 1)
   (KRN C e R -15)
   (KRN C o R -15)
   (KRN C u R -10)
   (KRN C y R -45)
   (KRN O 32 R -2) (comment ae)
   (KRN O 36 R -19) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 37 R -1) (comment Oslash)
   (KRN O 55 R 23) (comment hyphen)
   (KRN C A R -1)
   (KRN C C R -1)
   (KRN C G R -3)
   (KRN C O R -1)
   (KRN C S R 3)
   (KRN C T R -60)
   (KRN C U R -18)
   (KRN C V R -74)
   (KRN C W R -58)
   (KRN C Y R -75)
   (KRN C u R -8)
   (KRN C y R -37)
   (KRN O 35 R 6) (comment AE)
   (KRN O 47 R -83) (comment quoteright)
   (KRN O 42 R -83) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 37 R -10) (comment Oslash)
   (KRN O 54 R -12) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -18)
   (KRN C C R -10)
   (KRN C G R -10)
   (KRN C O R -10)
   (KRN C a R -18)
   (KRN C e R -12)
   (KRN C o R -13)
   (KRN C u R -13)
   (KRN O 35 R -13) (comment AE)
   (KRN O 32 R -18) (comment ae)
   (KRN O 34 R -13) (comment oslash)
   (STOP)
   (LABEL C O)
   (KRN C A R -25)
   (KRN C T R -3)
   (KRN C V R -30)
   (KRN C W R -25)
   (KRN C X R -25)
   (KRN C Y R -36)
   (KRN O 35 R -24) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 54 R -60) (comment comma)
   (KRN O 55 R -22) (comment hyphen)
   (KRN O 56 R -90) (comment period)
   (KRN C A R -59)
   (KRN C J R -38)
   (KRN C a R -10)
   (KRN C e R -14)
   (KRN C o R -16)
   (KRN O 35 R -57) (comment AE)
   (KRN O 32 R -9) (comment ae)
   (KRN O 34 R -16) (comment oslash)
   (KRN O 33 R -16) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 34 R -24) (comment oslash)
   (KRN O 37 R -26) (comment Oslash)
   (KRN O 55 R -44) (comment hyphen)
   (KRN C C R -26)
   (KRN C G R -26)
   (KRN C O R -26)
   (KRN C T R -24)
   (KRN C U R -37)
   (KRN C V R -65)
   (KRN C W R -60)
   (KRN C Y R -60)
   (KRN C a R -2)
   (KRN C e R -14)
   (KRN C o R -24)
   (KRN C u R -14)
   (KRN C y R -32)
   (KRN O 32 R -6) (comment ae)
   (KRN O 36 R -24) (comment OE)
   (KRN O 33 R -21) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN C A R -30)
   (KRN C T R -18)
   (KRN C V R -20)
   (KRN C W R -20)
   (KRN C Y R -27)
   (KRN C t R -11)
   (KRN O 35 R -27) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 54 R -27) (comment comma)
   (KRN O 55 R -36) (comment hyphen)
   (KRN O 56 R -45) (comment period)
   (KRN O 72 R -26) (comment colon)
   (KRN O 73 R -26) (comment semicolon)
   (KRN C A R -53)
   (KRN C C R -2)
   (KRN C G R -2)
   (KRN C J R -7)
   (KRN C O R -5)
   (KRN C S R -9)
   (KRN C V R 14)
   (KRN C W R 19)
   (KRN C Y R 10)
   (KRN C a R -38)
   (KRN C c R -41)
   (KRN C e R -41)
   (KRN C g R -44)
   (KRN C i R -9)
   (KRN C j R -10)
   (KRN C o R -32)
   (KRN C r R -24)
   (KRN C s R -36)
   (KRN C u R -38)
   (KRN C v R -51)
   (KRN C w R -51)
   (KRN C y R -49)
   (KRN O 35 R -46) (comment AE)
   (KRN O 37 R -5) (comment Oslash)
   (KRN O 32 R -40) (comment ae)
   (KRN O 34 R -32) (comment oslash)
   (KRN O 36 R -5) (comment OE)
   (STOP)
   (LABEL C U)
   (KRN O 54 R -31) (comment comma)
   (KRN O 56 R -28) (comment period)
   (KRN C A R -43)
   (KRN C m R -20)
   (KRN C n R -20)
   (KRN C p R -18)
   (KRN C r R -6)
   (KRN O 35 R -39) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 54 R -100) (comment comma)
   (KRN O 55 R -60) (comment hyphen)
   (KRN O 56 R -100) (comment period)
   (KRN O 72 R -60) (comment colon)
   (KRN O 73 R -59) (comment semicolon)
   (KRN C A R -84)
   (KRN C C R -38)
   (KRN C G R -38)
   (KRN C O R -38)
   (KRN C S R -35)
   (KRN C T R 9)
   (KRN C a R -80)
   (KRN C e R -70)
   (KRN C g R -65)
   (KRN C i R -20)
   (KRN C o R -75)
   (KRN C r R -40)
   (KRN C u R -50)
   (KRN C y R -50)
   (KRN O 35 R -73) (comment AE)
   (KRN O 37 R -38) (comment Oslash)
   (KRN O 32 R -80) (comment ae)
   (KRN O 34 R -75) (comment oslash)
   (STOP)
   (LABEL C W)
   (KRN O 54 R -80) (comment comma)
   (KRN O 55 R -40) (comment hyphen)
   (KRN O 56 R -92) (comment period)
   (KRN O 72 R -33) (comment colon)
   (KRN O 73 R -47) (comment semicolon)
   (KRN C A R -102)
   (KRN C C R -33)
   (KRN C G R -38)
   (KRN C O R -33)
   (KRN C S R -24)
   (KRN C T R 16)
   (KRN C a R -60)
   (KRN C e R -60)
   (KRN C g R -57)
   (KRN C i R -13)
   (KRN C o R -70)
   (KRN C r R -30)
   (KRN C u R -30)
   (KRN C y R -45)
   (KRN O 35 R -88) (comment AE)
   (KRN O 37 R -33) (comment Oslash)
   (KRN O 32 R -60) (comment ae)
   (KRN O 34 R -70) (comment oslash)
   (STOP)
   (LABEL C X)
   (KRN O 34 R -27) (comment oslash)
   (KRN O 37 R -38) (comment Oslash)
   (KRN O 55 R -45) (comment hyphen)
   (KRN C C R -35)
   (KRN C O R -38)
   (KRN C Q R -38)
   (KRN C a R -7)
   (KRN C e R -29)
   (KRN C o R -27)
   (KRN C u R -18)
   (KRN C y R -63)
   (STOP)
   (LABEL C Y)
   (KRN O 54 R -75) (comment comma)
   (KRN O 55 R -80) (comment hyphen)
   (KRN O 56 R -93) (comment period)
   (KRN O 72 R -66) (comment colon)
   (KRN O 73 R -61) (comment semicolon)
   (KRN C A R -75)
   (KRN C C R -50)
   (KRN C G R -51)
   (KRN C O R -51)
   (KRN C S R -43)
   (KRN C T R 12)
   (KRN C a R -80)
   (KRN C e R -66)
   (KRN C g R -73)
   (KRN C i R -17)
   (KRN C o R -67)
   (KRN C p R -57)
   (KRN C u R -59)
   (KRN C v R -62)
   (KRN O 35 R -67) (comment AE)
   (KRN O 37 R -51) (comment Oslash)
   (KRN O 32 R -85) (comment ae)
   (KRN O 34 R -67) (comment oslash)
   (STOP)
   (LABEL C Z)
   (KRN C v R -33)
   (KRN C w R -34)
   (KRN C y R -33)
   (STOP)
   (LABEL O 134) (comment quotedblleft)
   (KRN C A R -89)
   (KRN C T R 13)
   (KRN C V R -1)
   (KRN C W R 4)
   (KRN C Y R -3)
   (KRN O 35 R -87) (comment AE)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 134)
   (KRN C A R -114)
   (KRN C T R -11)
   (KRN C V R -25)
   (KRN C W R -20)
   (KRN C Y R -27)
   (KRN O 35 R -112) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN C j R -8)
   (KRN C v R -32)
   (KRN C w R -33)
   (KRN C y R -27)
   (KRN O 47 R -41) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN C v R -18)
   (KRN C w R -18)
   (KRN C y R -20)
   (STOP)
   (LABEL C c)
   (KRN C h R -16)
   (KRN C k R -22)
   (STOP)
   (LABEL C e)
   (KRN C t R -9)
   (KRN C v R -19)
   (KRN C w R -19)
   (KRN C x R -21)
   (KRN C y R -21)
   (KRN O 47 R -20) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 13)
   (LIG C l O 15)
   (LIG C i O 14)
   (KRN C a R -26)
   (KRN C e R -34)
   (KRN C j R 7)
   (KRN C o R -32)
   (KRN C s R -16)
   (KRN C t R 10)
   (KRN O 32 R -27) (comment ae)
   (KRN O 34 R -37) (comment oslash)
   (KRN O 33 R -36) (comment oe)
   (KRN O 47 R 16) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN C a R -11)
   (KRN C e R -15)
   (KRN C l R -2)
   (KRN C r R 10)
   (KRN O 32 R -11) (comment ae)
   (STOP)
   (LABEL C h)
   (KRN C y R -20)
   (KRN O 47 R -39) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -18)
   (KRN C j R -34)
   (STOP)
   (LABEL C k)
   (KRN O 34 R -21) (comment oslash)
   (KRN O 54 R 5) (comment comma)
   (KRN O 55 R -49) (comment hyphen)
   (KRN O 56 R -1) (comment period)
   (KRN C a R 1)
   (KRN C e R -13)
   (KRN C g R -8)
   (KRN C o R -21)
   (KRN C s R 5)
   (KRN C u R 14)
   (KRN O 32 R -2) (comment ae)
   (STOP)
   (LABEL C l)
   (KRN C v R -21)
   (KRN C y R -21)
   (STOP)
   (LABEL C m)
   (KRN C p R -3)
   (KRN C v R -20)
   (KRN C w R -20)
   (KRN C y R -20)
   (STOP)
   (LABEL C n)
   (KRN C T R -36)
   (KRN C p R -1)
   (KRN C v R -31)
   (KRN C w R -32)
   (KRN C y R -24)
   (KRN O 47 R -40) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN C T R -87)
   (KRN C t R -8)
   (KRN C v R -22)
   (KRN C w R -22)
   (KRN C x R -22)
   (KRN C y R -22)
   (KRN O 47 R -36) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN C t R -1)
   (KRN C y R -7)
   (STOP)
   (LABEL C q)
   (KRN C c R -3)
   (KRN C u R -13)
   (STOP)
   (LABEL C r)
   (KRN O 54 R -26) (comment comma)
   (KRN O 55 R -29) (comment hyphen)
   (KRN O 56 R -48) (comment period)
   (KRN O 72 R -8) (comment colon)
   (KRN O 73 R -7) (comment semicolon)
   (KRN C a R -2)
   (KRN C c R -2)
   (KRN C d R -2)
   (KRN C e R -2)
   (KRN C f R 19)
   (KRN C g R -16)
   (KRN C h R -2)
   (KRN C i R 19)
   (KRN C j R 13)
   (KRN C k R -7)
   (KRN C l R -7)
   (KRN C m R 20)
   (KRN C n R 21)
   (KRN C o R -6)
   (KRN C p R 25)
   (KRN C q R -10)
   (KRN C r R 26)
   (KRN C t R 23)
   (KRN C u R 24)
   (KRN C v R 20)
   (KRN C w R 19)
   (KRN C x R 16)
   (KRN C y R 21)
   (KRN C z R 2)
   (KRN O 32 R -3) (comment ae)
   (KRN O 34 R -6) (comment oslash)
   (KRN O 33 R -6) (comment oe)
   (KRN O 47 R -17) (comment quoteright)
   (STOP)
   (LABEL C s)
   (KRN C t R -8)
   (KRN O 47 R -35) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 34 R -2) (comment oslash)
   (KRN O 72 R 2) (comment colon)
   (KRN O 73 R 6) (comment semicolon)
   (KRN C S R 2)
   (KRN C a R 10)
   (KRN C h R 8)
   (KRN C o R -2)
   (KRN O 32 R 8) (comment ae)
   (KRN O 47 R -30) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -37) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 54 R -66) (comment comma)
   (KRN O 55 R -28) (comment hyphen)
   (KRN O 56 R -74) (comment period)
   (KRN O 72 R -21) (comment colon)
   (KRN O 73 R -17) (comment semicolon)
   (KRN C a R -20)
   (KRN C c R -28)
   (KRN C e R -24)
   (KRN C g R -42)
   (KRN C l R -31)
   (KRN C o R -27)
   (KRN C s R -13)
   (KRN O 32 R -20) (comment ae)
   (KRN O 34 R -27) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 54 R -50) (comment comma)
   (KRN O 55 R -24) (comment hyphen)
   (KRN O 56 R -68) (comment period)
   (KRN O 72 R -12) (comment colon)
   (KRN O 73 R -12) (comment semicolon)
   (KRN C a R -28)
   (KRN C c R -21)
   (KRN C e R -18)
   (KRN C g R -33)
   (KRN C l R -34)
   (KRN C o R -26)
   (KRN C s R -23)
   (KRN O 32 R -29) (comment ae)
   (KRN O 34 R -26) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 34 R -29) (comment oslash)
   (KRN C a R -11)
   (KRN C c R -24)
   (KRN C e R -24)
   (KRN C o R -29)
   (KRN C q R -17)
   (STOP)
   (LABEL C y)
   (KRN O 54 R -53) (comment comma)
   (KRN O 55 R -18) (comment hyphen)
   (KRN O 56 R -71) (comment period)
   (KRN O 72 R -8) (comment colon)
   (KRN O 73 R -14) (comment semicolon)
   (KRN C a R -15)
   (KRN C c R -15)
   (KRN C e R -23)
   (KRN C g R -22)
   (KRN C l R -18)
   (KRN C o R -18)
   (KRN C s R -13)
   (KRN O 32 R -15) (comment ae)
   (KRN O 34 R -18) (comment oslash)
   (STOP)
   (LABEL O 173) (comment endash)
   (LIG O 55 O 174)
   (STOP)
   )
(CHARACTER O 0 (comment uni0393)
   (CHARWD R 587)
   (CHARHT R 662)
   )
(CHARACTER O 1 (comment uni0394)
   (CHARWD R 722)
   (CHARHT R 674)
   )
(CHARACTER O 2 (comment uni0398)
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER O 3 (comment uni039B)
   (CHARWD R 702)
   (CHARHT R 674)
   )
(CHARACTER O 4 (comment uni039E)
   (CHARWD R 643)
   (CHARHT R 662)
   )
(CHARACTER O 5 (comment uni03A0)
   (CHARWD R 722)
   (CHARHT R 662)
   )
(CHARACTER O 6 (comment uni03A3)
   (CHARWD R 624)
   (CHARHT R 662)
   )
(CHARACTER O 7 (comment uni03A5)
   (CHARWD R 722)
   (CHARHT R 674)
   )
(CHARACTER O 10 (comment uni03A6)
   (CHARWD R 763)
   (CHARHT R 662)
   )
(CHARACTER O 11 (comment uni03A8)
   (CHARWD R 746)
   (CHARHT R 690)
   )
(CHARACTER O 12 (comment uni03A9)
   (CHARWD R 744)
   (CHARHT R 676)
   )
(CHARACTER O 13 (comment ff)
   (CHARWD R 605)
   (CHARHT R 683)
   (CHARIC R 50)
   )
(CHARACTER O 14 (comment fi)
   (CHARWD R 558)
   (CHARHT R 683)
   )
(CHARACTER O 15 (comment fl)
   (CHARWD R 556)
   (CHARHT R 683)
   )
(CHARACTER O 16 (comment ffi)
   (CHARWD R 832)
   (CHARHT R 683)
   )
(CHARACTER O 17 (comment ffl)
   (CHARWD R 830)
   (CHARHT R 683)
   )
(CHARACTER O 20 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 460)
   )
(CHARACTER O 21 (comment uni0237)
   (CHARWD R 278)
   (CHARHT R 460)
   (CHARDP R 218)
   )
(CHARACTER O 22 (comment grave)
   (CHARWD R 333)
   (CHARHT R 678)
   )
(CHARACTER O 23 (comment acute)
   (CHARWD R 333)
   (CHARHT R 678)
   )
(CHARACTER O 24 (comment caron)
   (CHARWD R 333)
   (CHARHT R 674)
   )
(CHARACTER O 25 (comment breve)
   (CHARWD R 335)
   (CHARHT R 664)
   )
(CHARACTER O 26 (comment macron)
   (CHARWD R 333)
   (CHARHT R 601)
   )
(CHARACTER O 27 (comment ring)
   (CHARWD R 333)
   (CHARHT R 711)
   )
(CHARACTER O 30 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 215)
   )
(CHARACTER O 31 (comment germandbls)
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 9)
   )
(CHARACTER O 32 (comment ae)
   (CHARWD R 667)
   (CHARHT R 460)
   (CHARDP R 7)
   )
(CHARACTER O 33 (comment oe)
   (CHARWD R 722)
   (CHARHT R 460)
   (CHARDP R 10)
   )
(CHARACTER O 34 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 551)
   (CHARDP R 112)
   )
(CHARACTER O 35 (comment AE)
   (CHARWD R 889)
   (CHARHT R 662)
   )
(CHARACTER O 36 (comment OE)
   (CHARWD R 889)
   (CHARHT R 668)
   (CHARDP R 6)
   )
(CHARACTER O 37 (comment Oslash)
   (CHARWD R 722)
   (CHARHT R 734)
   (CHARDP R 80)
   )
(CHARACTER O 40 (comment space)
   (CHARWD R 250)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 676)
   (CHARDP R 9)
   )
(CHARACTER O 42 (comment quotedblright)
   (CHARWD R 444)
   (CHARHT R 676)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 500)
   (CHARHT R 662)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 727)
   (CHARDP R 87)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 747)
   (CHARHT R 706)
   (CHARDP R 19)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 778)
   (CHARHT R 676)
   (CHARDP R 13)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 676)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 676)
   (CHARDP R 177)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 676)
   (CHARDP R 177)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 685)
   (CHARHT R 547)
   (CHARDP R 41)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 102)
   (CHARDP R 141)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 257)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 100)
   (CHARDP R 11)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 676)
   (CHARDP R 14)
   (CHARIC R 9)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 14)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 14)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 662)
   (CHARDP R 8)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 22)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 278)
   (CHARHT R 459)
   (CHARDP R 11)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 278)
   (CHARHT R 459)
   (CHARDP R 141)
   )
(CHARACTER O 74 (comment exclamdown)
   (CHARWD R 330)
   (CHARHT R 468)
   (CHARDP R 218)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 685)
   (CHARHT R 386)
   )
(CHARACTER O 76 (comment questiondown)
   (CHARWD R 444)
   (CHARHT R 467)
   (CHARDP R 218)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 444)
   (CHARHT R 676)
   (CHARDP R 8)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 921)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C A
   (CHARWD R 722)
   (CHARHT R 674)
   )
(CHARACTER C B
   (CHARWD R 667)
   (CHARHT R 662)
   )
(CHARACTER C C
   (CHARWD R 667)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 662)
   )
(CHARACTER C E
   (CHARWD R 611)
   (CHARHT R 662)
   )
(CHARACTER C F
   (CHARWD R 556)
   (CHARHT R 662)
   )
(CHARACTER C G
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C H
   (CHARWD R 722)
   (CHARHT R 662)
   )
(CHARACTER C I
   (CHARWD R 333)
   (CHARHT R 662)
   )
(CHARACTER C J
   (CHARWD R 373)
   (CHARHT R 662)
   (CHARDP R 14)
   )
(CHARACTER C K
   (CHARWD R 722)
   (CHARHT R 662)
   (CHARIC R 1)
   )
(CHARACTER C L
   (CHARWD R 611)
   (CHARHT R 662)
   )
(CHARACTER C M
   (CHARWD R 889)
   (CHARHT R 662)
   )
(CHARACTER C N
   (CHARWD R 722)
   (CHARHT R 662)
   (CHARDP R 11)
   )
(CHARACTER C O
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C P
   (CHARWD R 557)
   (CHARHT R 662)
   )
(CHARACTER C Q
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 177)
   )
(CHARACTER C R
   (CHARWD R 667)
   (CHARHT R 662)
   )
(CHARACTER C S
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C T
   (CHARWD R 611)
   (CHARHT R 662)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 662)
   (CHARDP R 14)
   )
(CHARACTER C V
   (CHARWD R 722)
   (CHARHT R 662)
   (CHARDP R 11)
   )
(CHARACTER C W
   (CHARWD R 944)
   (CHARHT R 662)
   (CHARDP R 11)
   )
(CHARACTER C X
   (CHARWD R 722)
   (CHARHT R 662)
   )
(CHARACTER C Y
   (CHARWD R 722)
   (CHARHT R 662)
   )
(CHARACTER C Z
   (CHARWD R 612)
   (CHARHT R 662)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 134 (comment quotedblleft)
   (CHARWD R 444)
   (CHARHT R 676)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 136 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 674)
   )
(CHARACTER O 137 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 622)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 676)
   )
(CHARACTER C a
   (CHARWD R 444)
   (CHARHT R 460)
   (CHARDP R 10)
   )
(CHARACTER C b
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 10)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 460)
   (CHARDP R 10)
   )
(CHARACTER C d
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 10)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 460)
   (CHARDP R 10)
   )
(CHARACTER C f
   (CHARWD R 333)
   (CHARHT R 683)
   (CHARIC R 50)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 460)
   (CHARDP R 218)
   )
(CHARACTER C h
   (CHARWD R 500)
   (CHARHT R 683)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 683)
   )
(CHARACTER C j
   (CHARWD R 278)
   (CHARHT R 683)
   (CHARDP R 218)
   )
(CHARACTER C k
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARIC R 5)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 683)
   )
(CHARACTER C m
   (CHARWD R 778)
   (CHARHT R 460)
   )
(CHARACTER C n
   (CHARWD R 500)
   (CHARHT R 460)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 460)
   (CHARDP R 10)
   )
(CHARACTER C p
   (CHARWD R 500)
   (CHARHT R 460)
   (CHARDP R 217)
   )
(CHARACTER C q
   (CHARWD R 500)
   (CHARHT R 460)
   (CHARDP R 217)
   )
(CHARACTER C r
   (CHARWD R 333)
   (CHARHT R 460)
   (CHARIC R 2)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 459)
   (CHARDP R 10)
   )
(CHARACTER C t
   (CHARWD R 278)
   (CHARHT R 579)
   (CHARDP R 10)
   (CHARIC R 1)
   )
(CHARACTER C u
   (CHARWD R 500)
   (CHARHT R 450)
   (CHARDP R 10)
   )
(CHARACTER C v
   (CHARWD R 500)
   (CHARHT R 450)
   (CHARDP R 14)
   )
(CHARACTER C w
   (CHARWD R 722)
   (CHARHT R 450)
   (CHARDP R 14)
   )
(CHARACTER C x
   (CHARWD R 500)
   (CHARHT R 450)
   )
(CHARACTER C y
   (CHARWD R 500)
   (CHARHT R 450)
   (CHARDP R 218)
   )
(CHARACTER C z
   (CHARWD R 444)
   (CHARHT R 450)
   )
(CHARACTER O 173 (comment endash)
   (CHARWD R 500)
   (CHARHT R 250)
   )
(CHARACTER O 174 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 250)
   )
(CHARACTER O 175 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARIC R 43)
   )
(CHARACTER O 176 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 638)
   )
(CHARACTER O 177 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 622)
   )
